==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_functions/mp0116_getgriddataonly_001_result/FUNCTION_REQUEST_TYPE.java <==

package net.datastream.schemas.mp_functions.mp0116_getgriddataonly_001_result;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour FUNCTION_REQUEST_TYPE.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * <p>
 * <pre>
 * &lt;simpleType name="FUNCTION_REQUEST_TYPE">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="LIST.COUNT.STORED"/>
 *     &lt;enumeration value="LIST.DATA_ONLY.STORED"/>
 *     &lt;enumeration value="LOV.DATA_ONLY.STORED"/>
 *     &lt;enumeration value="LIST.LAYOUT.SAVE.OTF"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "FUNCTION_REQUEST_TYPE")
@XmlEnum
public enum FUNCTION_REQUEST_TYPE {

    @XmlEnumValue("LIST.COUNT.STORED")
    LIST___COUNT___STORED("LIST.COUNT.STORED"),
    @XmlEnumValue("LIST.DATA_ONLY.STORED")
    LIST___DATA___ONLY___STORED("LIST.DATA_ONLY.STORED"),
    @XmlEnumValue("LOV.DATA_ONLY.STORED")
    LOV___DATA___ONLY___STORED("LOV.DATA_ONLY.STORED"),
    @XmlEnumValue("LIST.LAYOUT.SAVE.OTF")
    LIST___LAYOUT___SAVE___OTF("LIST.LAYOUT.SAVE.OTF");
    private final String value;

    FUNCTION_REQUEST_TYPE(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static FUNCTION_REQUEST_TYPE fromValue(String v) {
        for (FUNCTION_REQUEST_TYPE c: FUNCTION_REQUEST_TYPE.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_functions/mp0116_getgriddataonly_001_result/FUNCTION_REQUEST_TYPE.java <==

package net.datastream.schemas.mp_functions.mp0116_getgriddataonly_001_result;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for FUNCTION_REQUEST_TYPE.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="FUNCTION_REQUEST_TYPE">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="LIST.COUNT.STORED"/>
 *     &lt;enumeration value="LIST.DATA_ONLY.STORED"/>
 *     &lt;enumeration value="LOV.DATA_ONLY.STORED"/>
 *     &lt;enumeration value="LIST.LAYOUT.SAVE.OTF"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "FUNCTION_REQUEST_TYPE")
@XmlEnum
public enum FUNCTION_REQUEST_TYPE {

    @XmlEnumValue("LIST.COUNT.STORED")
    LIST___COUNT___STORED("LIST.COUNT.STORED"),
    @XmlEnumValue("LIST.DATA_ONLY.STORED")
    LIST___DATA___ONLY___STORED("LIST.DATA_ONLY.STORED"),
    @XmlEnumValue("LOV.DATA_ONLY.STORED")
    LOV___DATA___ONLY___STORED("LOV.DATA_ONLY.STORED"),
    @XmlEnumValue("LIST.LAYOUT.SAVE.OTF")
    LIST___LAYOUT___SAVE___OTF("LIST.LAYOUT.SAVE.OTF");
    private final String value;

    FUNCTION_REQUEST_TYPE(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static FUNCTION_REQUEST_TYPE fromValue(String v) {
        for (FUNCTION_REQUEST_TYPE c: FUNCTION_REQUEST_TYPE.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
